//
//  AdmostSDKPlugin.m
//  admost_flutter_plugin
//
//  Created by Mehmet Karagöz on 9.12.2019.
//

#import "AdmostSDKPlugin.h"
#import "AdmostBannerFactory.h"
#import <AMRSDK/AMRSDK.h>
#import <AppTrackingTransparency/AppTrackingTransparency.h>


@implementation AdmostSDKPlugin

+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
    AdmostSDKPlugin *instance = [[AdmostSDKPlugin alloc] init];
    FlutterMethodChannel *defaultChannel = [FlutterMethodChannel methodChannelWithName:@"admost_flutter"
                                                                       binaryMessenger:registrar.messenger];
    [registrar addMethodCallDelegate:instance channel:defaultChannel];
    
    AdmostBannerFactory *bannerFactory = [AdmostBannerFactory bannerFactoryWithMessenger:registrar.messenger];
    [registrar registerViewFactory:bannerFactory
                            withId:@"admost_flutter/banner"];
}

- (void)handleMethodCall:(FlutterMethodCall *)call result:(FlutterResult)result {
    /*if (call.arguments == nil ||
        ![call.arguments isKindOfClass:[NSDictionary class]]) {
        result(FlutterMethodNotImplemented);
        return;
    }*/
    
    NSDictionary *parameters = (NSDictionary *)call.arguments;
    
    
    if ([parameters objectForKey:@"subjectToCCPA"]) {
        NSString *stringParam = parameters[@"subjectToCCPA"];
        BOOL subjectToCCPA = [stringParam boolValue];
        
        [AMRSDK subjectToCCPA:subjectToCCPA];
    }
    
    if ([parameters objectForKey:@"subjectToGDPR"]) {
        NSString *stringParam = parameters[@"subjectToGDPR"];
        BOOL subjectToGDPR = [stringParam boolValue];
        
        [AMRSDK subjectToGDPR:subjectToGDPR];
    }
    
    if ([parameters objectForKey:@"userConsent"]) {
        NSString *stringParam = parameters[@"userConsent"];
        BOOL userConsent = [stringParam boolValue];
        
        [AMRSDK setUserConsent:userConsent];
    }
    
    NSString *appId = parameters[@"appId"];

    if ([call.method isEqualToString:@"initialize"]) {
        [AMRSDK startWithAppId:appId];
    } else if ([call.method isEqualToString:@"startTestSuite"]) {
        [AMRSDK startTesterInfoWithAppId:appId];
    } else if ([call.method isEqualToString:@"trackIAP"]) {
        double amount = [parameters[@"amount"] doubleValue];
        [AMRSDK trackIAP:parameters[@"identifier"] currencyCode:parameters[@"currencyCode"] amount:amount tags:parameters[@"tags"]];
    } else if ([call.method isEqualToString:@"setUserId"]) {
        NSString *userId = parameters[@"userId"];
        [AMRSDK setUserId:userId];
    } else if ([call.method isEqualToString:@"requestTrackingAuthorization"]) {
        if (@available(iOS 14, *)) {
            [ATTrackingManager requestTrackingAuthorizationWithCompletionHandler:^(ATTrackingManagerAuthorizationStatus status) {
                result([NSNumber numberWithInt:status]);
            }];
        } else {
            result(0);
        }
    } else if ([call.method isEqualToString:@"getTrackingAuthorizationStatus"]) {
        if (@available(iOS 14, *)) {
            result([NSNumber numberWithInt:[ATTrackingManager trackingAuthorizationStatus]]);
        } else {
            result(0);
        }
    } else {
        result(FlutterMethodNotImplemented);
    }
}

@end
