import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class Admost {
  /// Starts Admost mediation and analytics functions, it must be called at the very beginning of the application life cycle
  /// appId : Application id got from Admost dashboard
  String appId;
  String userConsent;
  String subjectToGDPR;
  String subjectToCCPA;
  Admost.initialize(
      {@required String appId,
      String userConsent,
      String subjectToGDPR,
      String subjectToCCPA}) {
    MethodChannel _channel = const MethodChannel('admost_flutter');

    this.appId = appId;
    Map<String, String> config = {
      "appId": appId,
      "userConsent": userConsent,
      "subjectToGDPR": subjectToGDPR,
      "subjectToCCPA": subjectToCCPA
    };

    _channel.invokeMethod('initialize', config);
  }

  /// Opens up test screen for ad network testing, available only for testers
  /// To be tester, Google Advertising Id has to be entered in the Admost Dashboard Testers screen
  Admost.startTestSuite(String appId) {
    Map<String, String> config = {"appId": appId};
    MethodChannel _channel = const MethodChannel('admost_flutter');
    _channel.invokeMethod('startTestSuite', config);
  }

  static void trackIAPForIOS(String identifier, String currencyCode, double amount,
      List<String> tags) {
    Map<String, dynamic> config = {
      "identifier": identifier,
      "currencyCode": currencyCode,
      "amount": amount,
      "tags": tags,
    };
    MethodChannel _channel = const MethodChannel('admost_flutter');
    _channel.invokeMethod('trackIAP', config);
  }

  static void trackIAPForAndroid(String originalJSON, String signature, String currencyCode, double price,
      List<String> tags) {
    Map<String, dynamic> config = {
      "originalJSON": originalJSON,
      "signature": signature,
      "currencyCode": currencyCode,
      "price": price,
      "tags": tags,
    };
    MethodChannel _channel = const MethodChannel('admost_flutter');
    _channel.invokeMethod('trackIAP', config);
  }

  static void setUserId(String userId) {
    Map<String, String> config = {"userId": userId};
    MethodChannel _channel = const MethodChannel('admost_flutter');
    _channel.invokeMethod('setUserId', config);
  }
}
